[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


A Python module for communicating with Crestron control processors via the
Crestron-over-IP (CIP) protocol.

**This module is a work-in-progress!**  My intention, once I have a functionally
complete and stable module, is to post it to PyPi.  As this project is my official leap
into learning Python (and Git/Github), it may take awhile.

